@@ -2,7 +2,7 @@ import asyncio
 import json
 import logging
 from typing import TYPE_CHECKING, List, Optional
-from swibots.api.common.models import User, MediaUploadRequest
+from swibots.api.common.models import User, MediaUploadRequest, Media
 from swibots.api.chat.models import Message, GroupChatHistory, InlineMarkup, InlineQuery, InlineQueryAnswer
 from swibots.error import SwitchError
 from swibots.utils.types import JSONDict
@@ -123,7 +123,7 @@ class MessageController:
         reply.replied_to_id = id
         return await self.send_message(reply, media)
 
-    async def reply_text(self, message: int | Message, text: str, inline_markup: InlineMarkup = None, media: MediaUploadRequest = None) -> Message:
+    async def reply_text(self, message: int | Message, text: str, inline_markup: InlineMarkup = None, media: MediaUploadRequest = None, cached_media: Media = None) -> Message:
         """Reply to a message with text
 
         Parameters:
@@ -141,7 +141,8 @@ class MessageController:
         else:
             id = message
 
-        m = Message(message=text, inline_markup=inline_markup)
+        m = Message(message=text, inline_markup=inline_markup,
+                    cached_media=cached_media)
 
         return await self.reply(id, m, media)
 
@@ -160,7 +161,7 @@ class MessageController:
         data = message.to_json_request()
         log.debug("Editing message %s", json.dumps(data))
         response = await self.client.put(f"{BASE_PATH}?id={message.id}", data=data)
-        return message
+        return self.client.build_object(Message, response.data["message"])
 
     async def edit_message_text(self, message: int | Message, text: str, inline_markup: InlineMarkup = None) -> Message:
         """Edit a message with text
@@ -567,6 +568,9 @@ class MessageController:
             answer = InlineQueryAnswer(query_id=query.query_id, title=None, results=answer, cache_time=0,
                                        is_personal=True, next_offset=None, pm_text=None, pm_parameter=None, user_id=query.user_id)
 
+        if not answer.user_id:
+            answer.user_id = query.user_id
+
         log.debug("Answering inline query %s", query.query_id)
         response = await self.client.post(f"{BASE_PATH}/inline/answer", answer.to_json_request())
         return response.data
