@@ -9,12 +9,11 @@ from swibots.utils.types import JSONDict
 class InlineKeyboardButton(SwitchObject):
     def __init__(
         self,
-        app: "swibots.App" = None,
         text: Optional[str] = None,
         url: Optional[str] = None,
         callback_data: Optional[str] = None,
     ):
-        super().__init__(app)
+        super().__init__(None)
         self.text = text
         self.url = url
         self.callback_data = callback_data
